#
# spec file for package qpdf
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_version 28
Name:           qpdf
Version:        10.3.1
Release:        150600.11.2
Summary:        Command-line tools and library for transforming PDF files
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            http://qpdf.sourceforge.net/
Source:         https://github.com/qpdf/qpdf/releases/download/release-qpdf-%{version}/qpdf-%{version}.tar.gz
Source1:        https://github.com/qpdf/qpdf/releases/download/release-qpdf-%{version}/qpdf-%{version}.tar.gz.asc
Source2:        qpdf.keyring
#PATCH-FIX-UPSTREAM Add support for OpenSSL 3
Patch0:         qpdf-support-openssl3.patch
Patch1:         qpdf-fix-openssl3.patch
#PATCH-FIX-SUSE disable fuzz-16214 on s390x (bsc#1218902)
%ifarch s390x
Patch2:         qpdf-s390x-disable-fuzz-16214.patch
%endif
BuildRequires:  gcc-c++
BuildRequires:  libjpeg8-devel
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(openssl)

%description
QPDF is a program that does structural, content-preserving
transformations on PDF files.  It could have been called something
like pdf-to-pdf.  It also provides many useful capabilities to
developers of PDF-producing software or for people who just want to
look at the innards of a PDF file to learn more about how they work.

QPDF offers many capabilities such as linearization (web
optimization), encrypt, and decryption of PDF files.  Note that QPDF
does not have the capability to create PDF files from scratch; it is
only used to create PDF files with special characteristics starting
from other PDF files or to inspect or extract information from
existing PDF files.

%package htmldoc
Summary:        Documentation files for qpdf
Group:          Documentation/HTML

%description htmldoc
This package contains the documentation for qpdf

%package devel
Summary:        Development files for qpdf PDF manipulation library
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       libstdc++-devel

%description devel
The qpdf-devel package contains header files and libraries necessary
for developing programs using the qpdf library.

%package -n libqpdf%{so_version}
Summary:        Shared libraries for qpdf
Group:          Development/Libraries/C and C++

%description -n libqpdf%{so_version}
This packages contains the shared libraries required for the qpdf
package.

%prep
%autosetup -p1

%build
export CXXFLAGS="%{optflags} -fvisibility-inlines-hidden"
%configure --disable-static \
           --enable-crypto-openssl \
           --disable-implicit-crypto \
           --docdir='${datarootdir}'/doc/packages/%{name} \
           --enable-show-failed-test-output
make %{?_smp_mflags}

%check
make %{?_smp_mflags} check
rm -rf qpdf/qtest # Unicode data can't be redistributed freely

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print

mkdir -p %{buildroot}%{_docdir}/%{name}/html
mv %{buildroot}%{_docdir}/%{name}/*.{css,html,pdf} %{buildroot}%{_docdir}/%{name}/html

%post -n libqpdf%{so_version} -p /sbin/ldconfig
%postun -n libqpdf%{so_version} -p /sbin/ldconfig

%files
%dir %{_docdir}/%{name}
%doc ChangeLog
%license Artistic-2.0
%{_bindir}/*
%{_mandir}/man1/*

%files htmldoc
%dir %{_docdir}/%{name}/html
%doc %{_docdir}/%{name}/html/*

%files -n libqpdf%{so_version}
%{_libdir}/libqpdf.so.%{so_version}*

%files devel
%{_includedir}/*
%{_libdir}/pkgconfig/libqpdf.pc
%{_libdir}/libqpdf.so

%changelog
* Wed Mar 13 2024 eugenio.paolantonio@suse.com
- Fix build issues in s390x (bsc#1218902):
  * Drop openssl3_2-fuzz-16214.patch: depending on the used build worker,
    the test output changes, so the patch might or might not work.
  * Add qpdf-s390x-disable-fuzz-16214.patch instead: this patch disables
    the test altogether, which is unreliable due to the reasons above.
    The test can be restored once a newer enough zlib package appears in
    SLE-15.
* Wed Jan 17 2024 otto.hollmann@suse.com
- Add support for OpenSSL 3.x (bsc#1217722)
  * Add qpdf-support-openssl3.patch qpdf-fix-openssl3.patch
- Temporary workaround for test fuzz-16214 (bsc#1218902)
  * Add openssl3_2-fuzz-16214.patch
* Fri Mar 12 2021 idonmez@suse.com
- Update to version 10.3.1
  * See http://qpdf.sourceforge.net/files/qpdf-manual.html#ref.release-notes
    for the complete changelog.
* Fri Mar  5 2021 idonmez@suse.com
- Update to version 10.3.0
  * See http://qpdf.sourceforge.net/files/qpdf-manual.html#ref.release-notes
    for the complete changelog.
* Thu Feb 25 2021 idonmez@suse.com
- Update to version 10.2.0
  * See http://qpdf.sourceforge.net/files/qpdf-manual.html#ref.release-notes
    for the complete changelog.
* Tue Jan  5 2021 idonmez@suse.com
- Update to version 10.1.0
  * See http://qpdf.sourceforge.net/files/qpdf-manual.html#ref.release-notes
    for the complete changelog.
* Sun Nov 22 2020 idonmez@suse.com
- Update to version 10.0.4
  * Fix a handful of integer overflows.
* Fri Oct 30 2020 idonmez@suse.com
- Update to version 10.0.3
  * Fixes a regression introduced in 10.0.2
* Wed Oct 28 2020 idonmez@suse.com
- Update to version 10.0.2
  * Bug fixes and performance improvements
  * See http://qpdf.sourceforge.net/files/qpdf-manual.html#ref.release-notes
    for a complete changelog.
* Fri Apr 10 2020 idonmez@suse.com
- Update to version 10.0.1
  * Fixes a regression in QPDFObjectHandle::getStreamData
* Mon Apr  6 2020 idonmez@suse.com
- Update to version 10.0.0
  * Several internal optimizations
  * OpenSSL support as alternative crypto provider
  * Bug fixes
  * See http://qpdf.sourceforge.net/files/qpdf-manual.html#ref.release-notes
    for the complete changelog.
- Add BR on pkgconfig(openssl) to add support for OpenSSL crypto
  provider and enable with --enable-crypto-openssl.
- Drop BR on pkgconfig(gnutls) now that we have OpenSSL support.
- Pass --disable-implicit-crypto to configure to make sure weak
  crypto code is disabled.
* Mon Jan 27 2020 idonmez@suse.com
- Update to version 9.1.1
  * fix-qdf is rewritten in C++
  * Added options --is-encrypted and --requires-password for testing
    whether a file is encrypted or requires a password other than
    the supplied (or empty) password.
  * Added encrypt key to JSON options. With the exception of the
    reconstructed user password for older encryption formats,
    this provides the same information as --show-encryption but in
    a consistent, parseable format. See output of qpdf --json-help
    for details.
  * In QDF mode, be sure not to write more than one XRef stream to a
    file, even when --preserve-unreferenced is used. fix-qdf
    assumes that there is only one XRef stream, and that it appears
    at the end of the file.
  * When externalizing inline images, properly handle images whose
    color space is a reference to an object in the page's resource
    dictionary.
* Sun Nov 17 2019 idonmez@suse.com
- Update to version 9.1.0
  * Incorporate contribution from Masamichi Hosoda to properly handle
    signature dictionaries by not including them in object streams,
    formatting the Contents key has a hexadecimal string,
    and excluding the /Contents key from encryption and decryption.
  * Incorporate contribution from Masamichi Hosoda to provide new API
    calls for getting file-level information about input and output files,
    enabling certain operations on the files at the file level rather
    than the object level. New methods include QPDF::getXRefTable(),
    QPDFObjectHandle::getParsedOffset(),
    QPDFWriter::getRenumberedObjGen(QPDFObjGen),
    and QPDFWriter::getWrittenXRefTable().
  * Support build-time and runtime selectable crypto providers.
    This includes the addition of new classes QPDFCryptoProvider
    and QPDFCryptoImpl and the recognition of the QPDF_CRYPTO_PROVIDER
    environment variable. Crypto providers are described in depth
    in Section 2.3, “Crypto Providers”.
  * Addition of the --show-crypto option in support of selectable
    crypto providers, as described in Section 2.3, “Crypto Providers”.
  * Allow :even or :odd to be appended to numeric ranges for
    specification of the even or odd pages from among the pages
    specified in the range.
  * Add BR on pkgconfig(gnutls) to add support for GnuTLS for encryption
  operations.
* Mon Oct 14 2019 idonmez@suse.com
- Update to version 9.0.2
  * Fix the name of the temporary file used by --replace-input so
    that it doesn't require path splitting and works with paths
    include directories.
* Fri Sep 20 2019 idonmez@suse.com
- Update to version 9.0.1
  * Upstream fixed bsc#1150151, removed explicit -fsigned-chars
    from CXXFLAGS
  * See included ChangeLog file for the complete changelog
* Tue Sep 10 2019 mgorse@suse.com
- Add -fsigned-char to CXXFLAGS. Otherwise, tests fail on ppc64le,
  s390x, and aarch64 (bsc#1150151).
* Sun Sep  1 2019 idonmez@suse.com
- Update to version 9.0.0
  * See included ChangeLog file for the complete changelog
* Mon Apr 29 2019 idonmez@suse.com
- Update to version 8.4.1
  * See included ChangeLog file for the complete changelog
* Mon Feb  4 2019 idonmez@suse.com
- Update to version 8.4.0
  See included ChangeLog file for the complete changelog
- Drop qpdf-data-loss-fix.patch, fixed upstream.
* Mon Jan 21 2019 idonmez@suse.com
- Update to version 8.3.0
  See included ChangeLog file for the complete changelog
- Add qpdf-data-loss-fix.patch to fix
  https://github.com/qpdf/qpdf/issues/276
* Mon Aug 20 2018 idonmez@suse.com
- Update to version 8.2.1
  Command-line Enchancements
  * Add --keep-files-open=[yn] to override default determination
    of whether to keep files open when merging.
- Update to version 8.2.0
  Command-line Enhancements
  * Add --no-warn option to suppress issuing warning messages.
    If there are any conditions that would have caused warnings
    to be issued, the exit status is still 3.
  Bug fixesd and Optimizations
  * Performance fix: optimize page merging operation to avoid
    unnecessary open/close calls on files being merged. This
    solves a dramatic slow-down that was observed when merging
    certain types of files.
  * Optimize how memory was used for the TIFF predictor,
    drastically improving performance and memory usage for files
    containing high-resolution images compressed with Flate
    using the TIFF predictor.
  * Bug fix: end of line characters were not properly handled
    inside strings in some cases.
  * Bug fix: using --progress on very small files could cause
    an infinite loop.
  API enhancements
  * Add new class QPDFSystemError, derived from std::runtime_error,
    which is now thrown by QUtil::throw_system_error. This enables
    the triggering errno value to be retrieved.
  * Add ClosedFileInputSource::stayOpen method, enabling a
    ClosedFileInputSource to stay open during manually indicated
    periods of high activity, thus reducing the overhead of
    frequent open/close operations.
* Tue Jun 26 2018 idonmez@suse.com
- Update to version 8.1.0
  Usability improvements:
  * When splitting files, qpdf detects fonts and images that the
    document metadata claims are referenced from a page but are
    not actually referenced and omits them from the output file.
  * When merging multiple PDF files, qpdf no longer leaves all
    the files open.
  * The --rotate option's syntax has been extended to make the
    page range optional. If you specify --rotate=angle without
    specifying a page range, the rotation will be applied to
    all pages.
  * When merging multiple files, the --verbose option now prints
    information about each file as it operates on that file.
  * When the --progress option is specified, qpdf will print a
    running indicator of its best guess at how far through the
    writing process it is.
  Bug fixes:
  * Properly decrypt files that use revision 3 of the standard
    security handler but use 40 bit keys
    (even though revision 3 supports 128-bit keys).
  * Limit depth of nested data structures to prevent crashes
    from certain types of malformed (malicious) PDFs.
  * In “newline before endstream” mode, insert the required
    extra newline before the endstream at the end of object streams.
  Please see included ChangeLog for complete changelog including
  API changes.
* Wed Mar  7 2018 idonmez@suse.com
- Update to version 8.0.2
  * Proper handling of pages with no content
  * Better handling of files with loops following cross reference
    tables
* Mon Mar  5 2018 idonmez@suse.com
- Update to version 8.0.1
  * Handle zlib streams with data checksum errors
  * In the command line tool, allow specification of page numbers
    counting from the end in page ranges.
* Tue Feb 27 2018 idonmez@suse.com
- Update to version 8.0.0
  * QPDFObjectHandle::getUTF8Val now properly treats non-Unicode
    strings as encoded with PDF Doc Encoding.
  * Add the option --coalesce-contents can be used to combine
    content streams of a page whose contents are an array of
    streams into a single stream.
  * Add function qpdf_check_pdf to the C API. This function does
    basic checking that is a subset of what qpdf --check performs.
  * Major enhancements to the lexical layer of qpdf. For a complete
    list of enhancements, please refer to the ChangeLog file.
  * New API for working with PDF content streams at a lexical level.
    The new class QPDFObjectHandle::TokenFilter allows the developer
    to provide token handlers.
* Mon Feb  5 2018 idonmez@suse.com
- Update to version 7.1.1
  * Fix one linearization bug affecting files whose first /ID
    component is not 16 bytes long
  * Fix some build issues
- Add signature and keyring
* Wed Jan 24 2018 avindra@opensuse.org
- Update to version 7.1.0
  * Allow raw encryption key to be specified in libary and command
    line with the QPDF::setPasswordIsHexKey method and
  - -password-is-hex-key option. Allow encryption key to be displayed
    with --show-encryption-key option. See
    https://blog.didierstevens.com/2017/12/28/cracking-encrypted-pdfs-part-3/
    for a discussion of using this for cracking encrypted PDFs. I hope
    that a future release of qpdf will include some additional
    recovery options that may also make use of this capability.
  * Fix lexical error: the PDF specification allows floating point
    numbers to end with "."
  * Fix link order in the build to avoid conflicts when building
    from source while an older version of qpdf is installed
  * Add support for TIFF predictor for LZW and Flate streams. Now
  * Clarify documentation around options that control parsing but
    not output creation. Two options: --suppress-recovery and
  - -ignore-xref-streams, were documented in the "Advanced
    Transformation Options" section of the manual and --help output
    even though they are not related to output. These are now
    described in a separate section called "Advanced Parsing Options."
  * Implement remaining PNG filters for decode. Prior versions could
    decode only the "up" filter. Now all PNG filters (sub, up,
    average, Paeth, optimal) are supported for decoding.
    The implementation of the remaining PNG filters changed the
    interface to the private Pl_PNGFilter class, but this class's
    header file is not in the installation, and there is no public
    interface to the class. Within the library, the class is never
    allocated on the stack; it is only ever dynamically allocated. As
    such, this does not actually break binary compatibility of the
    library.  all predictor functions are supported
- cleanup with spec-cleaner
* Wed Sep 20 2017 idonmez@suse.com
- Update to version 7.0.0
  * License is now Apache-2.0
  * Add new libjpeg8-devel dependency
  * Improve the error message that is issued when QPDFWriter
  encounters a stream that can't be decoded. In particular, mention
  that the stream will be copied without filtering to avoid data
  loss.
  * Add new methods to the C API to correspond to new additions to
  QPDFWriter:
  - qpdf_set_compress_streams
  - qpdf_set_decode_level
  - qpdf_set_preserve_unreferenced_objects
  - qpdf_set_newline_before_endstream
  * Add support for writing PCLm files
  * QPDF now supports reading and writing streams encoded with
    JPEG or RunLength encoding. Library API enhancements and
    command-line options have been added to control this
    behavior. See command-line options --compress-streams
    and --decode-level and methods QPDFWriter::setCompressStreams
    and QPDFWriter::setDecodeLevel.
  * Page rotation is now supported and accessible from both the
    library and the command line.
  * Fixes CVE-2017-12595 bsc#1055960, CVE-2017-9208 bsc#1040311
    CVE-2017-9209 bsc#1040312, CVE-2017-9210 bsc#1040313,
    CVE-2017-11627 bsc#1050577, CVE-2017-11626 bsc#1050578,
    CVE-2017-11625 bsc#1050579, CVE-2017-11624 bsc#1050581
* Tue Nov 10 2015 idonmez@suse.com
- Update to version 6.0.0
  * Bump shared library version since 5.2.0 broke ABI.
* Sun Nov  8 2015 idonmez@suse.com
- Update to version 5.2.0
  * Support for deterministic /IDs for non-encrypted files. This is
    off by default.
  * Handle more invalid xref tables
* Mon May 25 2015 idonmez@suse.com
- Update to version 5.1.3
  * Handle object streams with more than 255 objects
  * Security fixes courtesy of Google Security Team
  * Properly handle pages that have no content
  * Robustness fixes for invalid PDF files
* Thu Jun 12 2014 idonmez@suse.com
- Update to version 5.1.2
  * Please see the included ChangeLog file
* Wed Jan 29 2014 jsmeix@suse.de
- Provide the license source file Artistic-2.0 in the binary RPM
  (fix declined IBS submitrequest 30947).
* Fri Jan 17 2014 idonmez@suse.com
- Update to version 5.1.1
  * Fixes https://github.com/qpdf/qpdf/issues/28
* Wed Dec 18 2013 idonmez@suse.com
- Update to version 5.1.0
  * Add ability to provide your own source of random numbers
    at runtime
  * More handling of damaged PDF files
* Tue Oct 22 2013 idonmez@suse.com
- Update to version 5.0.1
  * Some security fixes, courtesy of Redhat
* Wed Jul 10 2013 idonmez@suse.com
- Update to 5.0.0
  * Same as 4.2.0 but shared lib version bumped due to ABI changes
- Apply shared library packaging policy
* Mon Jul  8 2013 idonmez@suse.com
- Update to version 4.2.0
  * Fixes bug that would result in the loss of compressible objects
    whose generation numbers were greater than 0 when generating
    object streams.
  * Added better API calls for handling object ID and generation
    together as a QPDFObjGen.
  * Added --show-npages option to the qpdf command-line tool.
  * Several small enhancements to make qpdf able to handle a wider
    range of broken input files.
* Sun Apr 14 2013 idonmez@suse.com
- Update to version 4.1.0
  * New API calls for parsing PDF content streams
  * qpdf --check now parses all pages' content streams in addition
    to doing other checks.
  * Overridden compressed objects are properly handled.
- Drop qpdf-ppc64.patch: merged upstream
* Thu Jan  3 2013 dvaleev@suse.com
- Detect binary attachments better (qpdf-ppc64.patch)
  This fix eliminates a false test failure on some platforms and makes
  the binary test work properly whether characters with the high bit
  set, when treated as integers, are negative or not.
- pass --enable-show-failed-test-output to configure, to see
  detailed failure reason in build log.
* Mon Dec 31 2012 idonmez@suse.com
- Update to version 4.0.0
  * Support for Acrobat X & XI encryption
  * Support for extension levels in PDF version information.
  * New methods for supporting read and write from/to arbitrary sources.
  * Support for unencrypted files with encrypted attachments.
  * Support for files with junk preceding the PDF header.
* Fri Sep  7 2012 idonmez@suse.com
- Update to version 3.0.2
  * Calling QPDFWriter::setOutputMemory would result in a
  segmentation fault from write() if setStaticID() was not used.
  * New method call QPDFWriter::setExtraHeaderText to add text
  * Make it so that you can write the same QPDF object through two
  different QPDFWriter objects that both have linearization enabled.
* Sat Aug 11 2012 idonmez@suse.com
- Update to version 3.0.1
  * qpdf may falsely report premature EOF when reading files that
    have object streams that end with scalars not followed by
    whitespace.
* Thu Aug  2 2012 idonmez@suse.com
- Update to version 3.0.0
  * Page-based splitting and merging
  * Support for large files
  * The ability to set the encryption parameters of one file by copying
    them from another file.
  * Support for creating PDF files from scratch
- Drop applied patches
* Sun Apr 22 2012 dimstar@opensuse.org
- Add qpdf-gcc47.patch: Fix build with gcc 4.7.
* Mon Feb 27 2012 dmueller@suse.de
- fix build with pcre 8.30
* Tue Jan 24 2012 jengelh@medozas.de
- Remove redundant sections (see specfile guidelines)
* Mon Jan 23 2012 crrodriguez@opensuse.org
- Fix devel package requires
- Build with -fvisibility-inlines-hidden, test suite
  confirms it works and saves a few dozens of entries in the
  exported symbol table.
* Mon Jan  2 2012 idonmez@suse.com
- Update to v2.3.1
  * Fix threading problem with PCRE usage
* Thu Aug  4 2011 idonmez@novell.com
- Update to v2.2.4
  * Build system fixes
- Drop qpdf-gcc46.patch and qpdf-nostrip.patch: applied upstream
* Wed Aug  3 2011 idonmez@novell.com
- Remove unicode data to make sure its not redistributed
* Thu Jun 23 2011 idonmez@novell.com
- Add qpdf-nostrip.patch: don't strip libraries
* Wed Jun 22 2011 idonmez@novell.com
- Update to v2.3.3
  * API improvements
  * Compatibility fixes with some PDF files
* Mon Apr 28 2008 ejb@ql.org
- Initial packaging
